@@ -2,11 +2,12 @@
 import os
 import shutil
 import tempfile
+from pyls import uris
 from pyls.config import Config
 from pyls.workspace import Document, Workspace
 from pyls.plugins import pycodestyle_lint, pyflakes_lint
 
-DOC_URI = __file__
+DOC_URI = uris.from_fs_path(__file__)
 DOC = """import sys
 
 def hello():
@@ -20,9 +21,9 @@ DOC_SYNTAX_ERR = """def hello()
 """
 
 
-def test_pycodestyle(config, workspace):
+def test_pycodestyle(config):
     doc = Document(DOC_URI, DOC)
-    diags = pycodestyle_lint.pyls_lint(config, workspace, doc)
+    diags = pycodestyle_lint.pyls_lint(config, doc)
 
     assert all([d['source'] == 'pycodestyle' for d in diags])
 
@@ -51,14 +52,14 @@ def test_pycodestyle_config():
     """
     # Create a workspace in tmp
     tmp = tempfile.mkdtemp()
-    workspace = Workspace(tmp)
-    doc_uri = 'file://' + tmp + '/' + 'test.py'
+    workspace = Workspace(uris.from_fs_path(tmp))
+    doc_uri = uris.from_fs_path(os.path.join(tmp, 'test.py'))
     workspace.put_document(doc_uri, DOC)
     doc = workspace.get_document(doc_uri)
-    config = Config(workspace.root, {})
+    config = Config(workspace.root_uri, {})
 
     # Make sure we get a warning for 'indentation contains tabs'
-    diags = pycodestyle_lint.pyls_lint(config, workspace, doc)
+    diags = pycodestyle_lint.pyls_lint(config, doc)
     assert [d for d in diags if d['code'] == 'W191']
 
     content = {
@@ -73,7 +74,7 @@ def test_pycodestyle_config():
             f.write(content)
 
         # And make sure we don't get any warnings
-        diags = pycodestyle_lint.pyls_lint(config, workspace, doc)
+        diags = pycodestyle_lint.pyls_lint(config, doc)
         assert len([d for d in diags if d['code'] == 'W191']) == 0 if working else 1
 
         os.unlink(os.path.join(tmp, conf_file))
